@@ -2,12 +2,33 @@ context("miscellaneous check for docx")
 
 source("utils.R")
 
-test_that("defaul template", {
+test_that("default template", {
   x <- read_docx()
   expect_equal(length( x ), 2)
   expect_true(file.exists(x$doc_obj$package_dirname()))
 })
 
+test_that("docx dim", {
+  x <- read_docx()
+  dims <- docx_dim(x)
+
+  expect_equal( names(dims), c("page", "landscape", "margins") )
+  expect_length( dims$page, 2 )
+  expect_length( dims$landscape, 1 )
+  expect_length( dims$margins, 6 )
+
+  expect_equal( dims$page, c(width=8.263889, height=11.694444), tolerance = .001 )
+
+})
+
+test_that("list bookmarks", {
+  template_file <- system.file(package = "officer", "doc_examples/example.docx")
+  x <- read_docx(path = template_file)
+  bookmarks <- docx_bookmarks(x)
+
+  expect_equal( bookmarks, c("bmk_1", "bmk_2") )
+})
+
 test_that("console printing", {
   x <- read_docx()
   x <- body_add_par(x, "Hello world", style = "Normal")
@@ -53,7 +74,7 @@ test_that("styles_info is returning a tidy df", {
 test_that("id are sequentially defined", {
   doc <- read_docx()
   any_img <- FALSE
-  img.file <- file.path( Sys.getenv("R_HOME"), "doc", "html", "logo.jpg" )
+  img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
   if( file.exists(img.file) ){
     doc <- body_add_img(x = doc, src = img.file, height = 1.06, width = 1.39 )
     any_img <- TRUE
@@ -104,7 +125,7 @@ test_that("cursor behavior", {
 
 })
 
-test_that("cursor remove", {
+test_that("body remove", {
   doc <- read_docx() %>%
     body_add_par("paragraph 1", style = "Normal") %>%
     body_add_par("paragraph 2", style = "Normal") %>%
@@ -120,6 +141,10 @@ test_that("cursor remove", {
 
   expect_equal( ds_$text, c("paragraph 1", "new 1", "paragraph 2", "new 2") )
 
+  doc <- read_docx()
+  doc <- body_remove(doc)
+  expect_warning(body_remove(doc), "There is nothing left to remove in the document")
+
 })
 
 
